Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(392)

Unified Diff: tests/html/audiocontext_test.dart

Issue 11419300: Dartifying dart:html type names. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Unminifying & fixing Stephen's feedback. Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/svg/dartium/svg_dartium.dart ('k') | tests/html/cache_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/html/audiocontext_test.dart
diff --git a/tests/html/audiocontext_test.dart b/tests/html/audiocontext_test.dart
index 62367530bc9897f60f2ce5ff15bbd7f4db6f335d..e2b471e68de8d9156840947d0d7f8bc30dd276a3 100644
--- a/tests/html/audiocontext_test.dart
+++ b/tests/html/audiocontext_test.dart
@@ -21,10 +21,10 @@ main() {
ArrayBufferView arrayBufferView = new Float32Array.fromList([]);
try {
// Test that native overload is chosen correctly. Native implementation
// should throw 'SYNTAX_ERR' DOMException because the buffer is empty.
AudioBuffer buffer = ctx.createBuffer(arrayBufferView.buffer, false);
} catch (e) {
- expect(e.code, equals(DOMException.SYNTAX_ERR));
+ expect(e.code, equals(DomException.SYNTAX_ERR));
}
});
« no previous file with comments | « sdk/lib/svg/dartium/svg_dartium.dart ('k') | tests/html/cache_test.dart » ('j') | no next file with comments »
@@ -21,10 +21,10 @@ main() {
try {
// Test that native overload is chosen correctly. Native implementation
- // should throw 'SYNTAX_ERR' DOMException because the buffer is empty.
+ // should throw 'SYNTAX_ERR' DomException because the buffer is empty.
AudioBuffer buffer = ctx.createBuffer(arrayBufferView.buffer, false);
} catch (e) {

Powered by Google App Engine
This is Rietveld 408576698